==> haskell-lifted-async-0.9.1.1-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.9.1.1
id: lifted-async-0.9.1.1-1nsVpeCMZ7FGJWE6uq96nN
key: lifted-async-0.9.1.1-1nsVpeCMZ7FGJWE6uq96nN
license: BSD3
copyright: Copyright (C) 2012-2017 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <maoe@foldr.in>
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
author: Mitsutoshi Aoe
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
abi: 3da966728d329353c39285507f5b9336
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/lifted-async-0.9.1.1
hs-libraries: HSlifted-async-0.9.1.1-1nsVpeCMZ7FGJWE6uq96nN
depends:
    async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4 base-4.9.0.0
    constraints-0.9.1-4sh8KFItdKjFIEFwHyUnLD
    lifted-base-0.2.3.11-6Z5sbMH60be9gIey8uuzks
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.9.1.1-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.9.1.1
id: lifted-async-0.9.1.1-1VctRUfYTRt3SEwncNx2yO
key: lifted-async-0.9.1.1-1VctRUfYTRt3SEwncNx2yO
license: BSD3
copyright: Copyright (C) 2012-2017 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <maoe@foldr.in>
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
author: Mitsutoshi Aoe
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
abi: 762d23e05b947acb5af616f9b5cab42e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/lifted-async-0.9.1.1
hs-libraries: HSlifted-async-0.9.1.1-1VctRUfYTRt3SEwncNx2yO
depends:
    async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4 base-4.9.0.0
    constraints-0.9.1-4sh8KFItdKjFIEFwHyUnLD
    lifted-base-0.2.3.11-D5Xv69EKf6L9rLXYpe3sxE
    monad-control-1.0.2.0-4qPEnRApnc4gRDkIzJcM5
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
